@@ -73,7 +73,7 @@ class PHP_CodeSniffer
      *
      * @var string
      */
-    const VERSION = '2.3.3';
+    const VERSION = '2.7.1';
 
     /**
      * Package stability; either stable, beta or alpha.
@@ -129,6 +129,16 @@ class PHP_CodeSniffer
      */
     protected $sniffs = array();
 
+    /**
+     * A mapping of sniff codes to fully qualified class names.
+     *
+     * The key is the sniff code and the value
+     * is the fully qualified name of the sniff class.
+     *
+     * @var array<string, string>
+     */
+    public $sniffCodes = array();
+
     /**
      * The listeners array, indexed by token type.
      *
@@ -503,11 +513,12 @@ class PHP_CodeSniffer
      *
      * @param string|array $standards    The set of code sniffs we are testing
      *                                   against.
-     * @param array        $restrictions The sniff codes to restrict the
+     * @param array        $restrictions The sniff codes to restrict the testing to.
+     * @param array        $exclusions   The sniff codes to exclude from testing.
      *
      * @return void
      */
-    public function initStandard($standards, array $restrictions=array())
+    public function initStandard($standards, array $restrictions=array(), array $exclusions=array())
     {
         $standards = (array) $standards;
 
@@ -522,13 +533,13 @@ class PHP_CodeSniffer
         // be detected properly for files created on a Mac with the /r line ending.
         ini_set('auto_detect_line_endings', true);
 
-        $sniffs = array();
-        foreach ($standards as $standard) {
-            $installed = $this->getInstalledStandardPath($standard);
+        if (defined('PHP_CODESNIFFER_IN_TESTS') === true && empty($restrictions) === false) {
+            // Should be one standard and one sniff being tested at a time.
+            $installed = $this->getInstalledStandardPath($standards[0]);
             if ($installed !== null) {
                 $standard = $installed;
             } else {
-                $standard = self::realpath($standard);
+                $standard = self::realpath($standards[0]);
                 if (is_dir($standard) === true
                     && is_file(self::realpath($standard.DIRECTORY_SEPARATOR.'ruleset.xml')) === true
                 ) {
@@ -536,20 +547,37 @@ class PHP_CodeSniffer
                 }
             }
 
-            if (PHP_CODESNIFFER_VERBOSITY === 1) {
-                $ruleset = simplexml_load_string(file_get_contents($standard));
-                if ($ruleset !== false) {
-                    $standardName = (string) $ruleset['name'];
+            $sniffs = $this->_expandRulesetReference($restrictions[0], dirname($standard));
+        } else {
+            $sniffs = array();
+            foreach ($standards as $standard) {
+                $installed = $this->getInstalledStandardPath($standard);
+                if ($installed !== null) {
+                    $standard = $installed;
+                } else {
+                    $standard = self::realpath($standard);
+                    if (is_dir($standard) === true
+                        && is_file(self::realpath($standard.DIRECTORY_SEPARATOR.'ruleset.xml')) === true
+                    ) {
+                        $standard = self::realpath($standard.DIRECTORY_SEPARATOR.'ruleset.xml');
+                    }
                 }
 
-                echo "Registering sniffs in the $standardName standard... ";
-                if (count($standards) > 1 || PHP_CODESNIFFER_VERBOSITY > 2) {
-                    echo PHP_EOL;
-                }
-            }
+                if (PHP_CODESNIFFER_VERBOSITY === 1) {
+                    $ruleset = simplexml_load_string(file_get_contents($standard));
+                    if ($ruleset !== false) {
+                        $standardName = (string) $ruleset['name'];
+                    }
 
-            $sniffs = array_merge($sniffs, $this->processRuleset($standard));
-        }//end foreach
+                    echo "Registering sniffs in the $standardName standard... ";
+                    if (count($standards) > 1 || PHP_CODESNIFFER_VERBOSITY > 2) {
+                        echo PHP_EOL;
+                    }
+                }
+
+                $sniffs = array_merge($sniffs, $this->processRuleset($standard));
+            }//end foreach
+        }//end if
 
         $sniffRestrictions = array();
         foreach ($restrictions as $sniffCode) {
@@ -557,7 +585,13 @@ class PHP_CodeSniffer
             $sniffRestrictions[] = $parts[0].'_sniffs_'.$parts[1].'_'.$parts[2].'sniff';
         }
 
-        $this->registerSniffs($sniffs, $sniffRestrictions);
+        $sniffExclusions = array();
+        foreach ($exclusions as $sniffCode) {
+            $parts = explode('.', strtolower($sniffCode));
+            $sniffExclusions[] = $parts[0].'_sniffs_'.$parts[1].'_'.$parts[2].'sniff';
+        }
+
+        $this->registerSniffs($sniffs, $sniffRestrictions, $sniffExclusions);
         $this->populateTokenListeners();
 
         if (PHP_CODESNIFFER_VERBOSITY === 1) {
@@ -716,6 +750,19 @@ class PHP_CodeSniffer
             $ownSniffs = $this->_expandSniffDirectory($rulesetDir.DIRECTORY_SEPARATOR.'Sniffs', $depth);
         }
 
+        // Process custom sniff config settings.
+        foreach ($ruleset->{'config'} as $config) {
+            if ($this->_shouldProcessElement($config) === false) {
+                continue;
+            }
+
+            $this->setConfigData((string) $config['name'], (string) $config['value'], true);
+            if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                echo str_repeat("\t", $depth);
+                echo "\t=> set config value ".(string) $config['name'].': '.(string) $config['value'].PHP_EOL;
+            }
+        }
+
         foreach ($ruleset->rule as $rule) {
             if (isset($rule['ref']) === false
                 || $this->_shouldProcessElement($rule) === false
@@ -789,7 +836,35 @@ class PHP_CodeSniffer
             }
         }//end foreach
 
-        if (empty($cliValues['files']) === true) {
+        // Set custom php ini values as CLI args.
+        foreach ($ruleset->{'ini'} as $arg) {
+            if ($this->_shouldProcessElement($arg) === false) {
+                continue;
+            }
+
+            if (isset($arg['name']) === false) {
+                continue;
+            }
+
+            $name      = (string) $arg['name'];
+            $argString = $name;
+            if (isset($arg['value']) === true) {
+                $value      = (string) $arg['value'];
+                $argString .= "=$value";
+            } else {
+                $value = 'true';
+            }
+
+            $cliArgs[] = '-d';
+            $cliArgs[] = $argString;
+
+            if (PHP_CODESNIFFER_VERBOSITY > 1) {
+                echo str_repeat("\t", $depth);
+                echo "\t=> set PHP ini value $name to $value".PHP_EOL;
+            }
+        }//end foreach
+
+        if (empty($cliValues['files']) === true && $cliValues['stdin'] === null) {
             // Process hard-coded file paths.
             foreach ($ruleset->{'file'} as $file) {
                 $file      = (string) $file;
@@ -802,19 +877,19 @@ class PHP_CodeSniffer
         }
 
         if (empty($cliArgs) === false) {
-            $this->cli->setCommandLineValues($cliArgs);
-        }
-
-        // Process custom sniff config settings.
-        foreach ($ruleset->{'config'} as $config) {
-            if ($this->_shouldProcessElement($config) === false) {
-                continue;
+            // Change the directory so all relative paths are worked
+            // out based on the location of the ruleset instead of
+            // the location of the user.
+            $inPhar = self::isPharFile($rulesetDir);
+            if ($inPhar === false) {
+                $currentDir = getcwd();
+                chdir($rulesetDir);
             }
 
-            $this->setConfigData((string) $config['name'], (string) $config['value'], true);
-            if (PHP_CODESNIFFER_VERBOSITY > 1) {
-                echo str_repeat("\t", $depth);
-                echo "\t=> set config value ".(string) $config['name'].': '.(string) $config['value'].PHP_EOL;
+            $this->cli->setCommandLineValues($cliArgs);
+
+            if ($inPhar === false) {
+                chdir($currentDir);
             }
         }
 
@@ -1283,11 +1358,13 @@ class PHP_CodeSniffer
      * @param array $files        Paths to the sniff files to register.
      * @param array $restrictions The sniff class names to restrict the allowed
      *                            listeners to.
+     * @param array $exclusions   The sniff class names to exclude from the
+     *                            listeners  list.
      *
      * @return void
      * @throws PHP_CodeSniffer_Exception If a sniff file path is invalid.
      */
-    public function registerSniffs($files, $restrictions)
+    public function registerSniffs($files, $restrictions, $exclusions)
     {
         $listeners = array();
 
@@ -1321,6 +1398,14 @@ class PHP_CodeSniffer
                 continue;
             }
 
+            // If they have specified a list of sniffs to exclude, check
+            // to see if this sniff is allowed.
+            if (empty($exclusions) === false
+                && in_array(strtolower($className), $exclusions) === true
+            ) {
+                continue;
+            }
+
             include_once $file;
 
             // Support the use of PHP namespaces. If the class name we included
@@ -1373,6 +1458,7 @@ class PHP_CodeSniffer
             $code = substr($code, 0, -5);
 
             $this->listeners[$listenerClass] = new $listenerClass();
+            $this->sniffCodes[$code]         = $listenerClass;
 
             // Set custom properties.
             if (isset($this->ruleset[$code]['properties']) === true) {
@@ -1665,6 +1751,7 @@ class PHP_CodeSniffer
         $firstContent = $contents;
         if ($contents === null && is_readable($filePath) === true) {
             $handle = fopen($filePath, 'r');
+            stream_set_blocking($handle, true);
             if ($handle !== false) {
                 $firstContent  = fgets($handle);
                 $firstContent .= fgets($handle);
@@ -2023,13 +2110,17 @@ class PHP_CodeSniffer
             $lowerVarType = strtolower($varType);
             switch ($lowerVarType) {
             case 'bool':
+            case 'boolean':
                 return 'boolean';
             case 'double':
             case 'real':
+            case 'float':
                 return 'float';
             case 'int':
+            case 'integer':
                 return 'integer';
             case 'array()':
+            case 'array':
                 return 'array';
             }//end switch
 
@@ -2205,7 +2296,8 @@ class PHP_CodeSniffer
             // Might be an actual ruleset file itself.
             // If it has an XML extension, let's at least try it.
             if (is_file($standard) === true
-                && substr(strtolower($standard), -4) === '.xml'
+                && (substr(strtolower($standard), -4) === '.xml'
+                || substr(strtolower($standard), -9) === '.xml.dist')
             ) {
                 return true;
             }
