@@ -46,7 +46,7 @@ if (file_exists($a = dirname(__FILE__).'/../CodeSniffer.php') === true) {
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_CLI
@@ -736,7 +736,13 @@ class PHP_CodeSniffer_CLI
                         // Passed report file is a file in the current directory.
                         $this->values['reportFile'] = getcwd().'/'.basename($this->values['reportFile']);
                     } else {
-                        $dir = PHP_CodeSniffer::realpath(getcwd().'/'.$dir);
+                        if ($dir{0} === '/') {
+                            // An absolute path.
+                            $dir = PHP_CodeSniffer::realpath($dir);
+                        } else {
+                            $dir = PHP_CodeSniffer::realpath(getcwd().'/'.$dir);
+                        }
+
                         if ($dir !== false) {
                             // Report file path is relative.
                             $this->values['reportFile'] = $dir.'/'.basename($this->values['reportFile']);
@@ -771,7 +777,13 @@ class PHP_CodeSniffer_CLI
                                 // Passed report file is a filename in the current directory.
                                 $output = getcwd().'/'.basename($output);
                             } else {
-                                $dir = PHP_CodeSniffer::realpath(getcwd().'/'.$dir);
+                                if ($dir{0} === '/') {
+                                    // An absolute path.
+                                    $dir = PHP_CodeSniffer::realpath($dir);
+                                } else {
+                                    $dir = PHP_CodeSniffer::realpath(getcwd().'/'.$dir);
+                                }
+
                                 if ($dir !== false) {
                                     // Report file path is relative.
                                     $output = $dir.'/'.basename($output);
