@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Formatting_DisallowMultipleStatementsSniff implements PHP_CodeSniffer_Sniff
@@ -54,8 +54,11 @@ class Generic_Sniffs_Formatting_DisallowMultipleStatementsSniff implements PHP_C
     {
         $tokens = $phpcsFile->getTokens();
 
-        $prev = $phpcsFile->findPrevious(array(T_SEMICOLON, T_OPEN_TAG), ($stackPtr - 1));
-        if ($prev === false || $tokens[$prev]['code'] === T_OPEN_TAG) {
+        $prev = $phpcsFile->findPrevious(array(T_SEMICOLON, T_OPEN_TAG, T_OPEN_TAG_WITH_ECHO), ($stackPtr - 1));
+        if ($prev === false
+            || $tokens[$prev]['code'] === T_OPEN_TAG
+            || $tokens[$prev]['code'] === T_OPEN_TAG_WITH_ECHO
+        ) {
             $phpcsFile->recordMetric($stackPtr, 'Multiple statements on same line', 'no');
             return;
         }
