@@ -23,7 +23,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_Files_EndFileNewlineUnitTest extends AbstractSniffUnitTest
@@ -46,13 +46,16 @@ class Generic_Tests_Files_EndFileNewlineUnitTest extends AbstractSniffUnitTest
         case 'EndFileNewlineUnitTest.3.inc':
         case 'EndFileNewlineUnitTest.3.js':
         case 'EndFileNewlineUnitTest.3.css':
-            return array(
-                    2 => 1,
-                   );
-            break;
+            return array(2 => 1);
+        case 'EndFileNewlineUnitTest.4.inc':
+            // HHVM just removes the entire comment token, as if it was never there.
+            if (defined('HHVM_VERSION') === true) {
+                return array();
+            }
+
+            return array(2 => 1);
         default:
             return array();
-            break;
         }//end switch
 
     }//end getErrorList()
