@@ -23,7 +23,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_Files_EndFileNoNewlineUnitTest extends AbstractSniffUnitTest
@@ -47,19 +47,26 @@ class Generic_Tests_Files_EndFileNoNewlineUnitTest extends AbstractSniffUnitTest
         case 'EndFileNoNewlineUnitTest.1.css':
         case 'EndFileNoNewlineUnitTest.1.js':
         case 'EndFileNoNewlineUnitTest.2.inc':
-            return array(
-                    3 => 1,
-                   );
-            break;
+            return array(3 => 1);
         case 'EndFileNoNewlineUnitTest.2.css':
         case 'EndFileNoNewlineUnitTest.2.js':
-            return array(
-                    2 => 1,
-                   );
-            break;
+            return array(2 => 1);
+        case 'EndFileNoNewlineUnitTest.5.inc':
+            // HHVM just removes the entire comment token, as if it was never there.
+            if (defined('HHVM_VERSION') === true) {
+                return array(1 => 1);
+            }
+
+            return array();
+        case 'EndFileNoNewlineUnitTest.6.inc':
+            // HHVM just removes the entire comment token, as if it was never there.
+            if (defined('HHVM_VERSION') === true) {
+                return array(1 => 1);
+            }
+
+            return array(2 => 1);
         default:
             return array();
-            break;
         }//end switch
 
     }//end getErrorList()
