@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PSR2_Sniffs_Files_EndFileNewlineSniff implements PHP_CodeSniffer_Sniff
@@ -60,6 +60,10 @@ class PSR2_Sniffs_Files_EndFileNewlineSniff implements PHP_CodeSniffer_Sniff
         $tokens    = $phpcsFile->getTokens();
         $lastToken = ($phpcsFile->numTokens - 1);
 
+        if ($tokens[$lastToken]['content'] === '') {
+            $lastToken--;
+        }
+
         // Hard-coding the expected \n in this sniff as it is PSR-2 specific and
         // PSR-2 enforces the use of unix style newlines.
         if (substr($tokens[$lastToken]['content'], -1) !== "\n") {
@@ -75,8 +79,10 @@ class PSR2_Sniffs_Files_EndFileNewlineSniff implements PHP_CodeSniffer_Sniff
 
         // Go looking for the last non-empty line.
         $lastLine = $tokens[$lastToken]['line'];
-        if ($tokens[$lastToken]['code'] === T_WHITESPACE) {
-            $lastCode = $phpcsFile->findPrevious(T_WHITESPACE, ($lastToken - 1), null, true);
+        if ($tokens[$lastToken]['code'] === T_WHITESPACE
+            || $tokens[$lastToken]['code'] === T_DOC_COMMENT_WHITESPACE
+        ) {
+            $lastCode = $phpcsFile->findPrevious(array(T_WHITESPACE, T_DOC_COMMENT_WHITESPACE), ($lastToken - 1), null, true);
         } else {
             $lastCode = $lastToken;
         }
