@@ -22,7 +22,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -344,7 +344,6 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             }
         }//end if
 
-        $nextToken  = $stackPtr;
         $keyUsed    = false;
         $singleUsed = false;
         $indices    = array();
@@ -367,14 +366,25 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                 continue;
             }
 
-            if ($tokens[$nextToken]['code'] === T_ARRAY) {
+            if ($tokens[$nextToken]['code'] === T_ARRAY
+                || $tokens[$nextToken]['code'] === T_OPEN_SHORT_ARRAY
+                || $tokens[$nextToken]['code'] === T_CLOSURE
+            ) {
                 // Let subsequent calls of this test handle nested arrays.
                 if ($tokens[$lastToken]['code'] !== T_DOUBLE_ARROW) {
                     $indices[] = array('value' => $nextToken);
                     $lastToken = $nextToken;
                 }
 
-                $nextToken = $tokens[$tokens[$nextToken]['parenthesis_opener']]['parenthesis_closer'];
+                if ($tokens[$nextToken]['code'] === T_ARRAY) {
+                    $nextToken = $tokens[$tokens[$nextToken]['parenthesis_opener']]['parenthesis_closer'];
+                } else if ($tokens[$nextToken]['code'] === T_OPEN_SHORT_ARRAY) {
+                    $nextToken = $tokens[$nextToken]['bracket_closer'];
+                } else {
+                    // T_CLOSURE.
+                    $nextToken = $tokens[$nextToken]['scope_closer'];
+                }
+
                 $nextToken = $phpcsFile->findNext(T_WHITESPACE, ($nextToken + 1), null, true);
                 if ($tokens[$nextToken]['code'] !== T_COMMA) {
                     $nextToken--;
@@ -383,42 +393,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                 }
 
                 continue;
-            }
-
-            if ($tokens[$nextToken]['code'] === T_OPEN_SHORT_ARRAY) {
-                // Let subsequent calls of this test handle nested arrays.
-                if ($tokens[$lastToken]['code'] !== T_DOUBLE_ARROW) {
-                    $indices[] = array('value' => $nextToken);
-                    $lastToken = $nextToken;
-                }
-
-                $nextToken = $tokens[$nextToken]['bracket_closer'];
-                $nextToken = $phpcsFile->findNext(T_WHITESPACE, ($nextToken + 1), null, true);
-                if ($tokens[$nextToken]['code'] !== T_COMMA) {
-                    $nextToken--;
-                } else {
-                    $lastToken = $nextToken;
-                }
-
-                continue;
-            }
-
-            if ($tokens[$nextToken]['code'] === T_CLOSURE) {
-                if ($tokens[$lastToken]['code'] !== T_DOUBLE_ARROW) {
-                    $indices[] = array('value' => $nextToken);
-                    $lastToken = $nextToken;
-                }
-
-                $nextToken = $tokens[$nextToken]['scope_closer'];
-                $nextToken = $phpcsFile->findNext(T_WHITESPACE, ($nextToken + 1), null, true);
-                if ($tokens[$nextToken]['code'] !== T_COMMA) {
-                    $nextToken--;
-                } else {
-                    $lastToken = $nextToken;
-                }
-
-                continue;
-            }
+            }//end if
 
             if ($tokens[$nextToken]['code'] !== T_DOUBLE_ARROW
                 && $tokens[$nextToken]['code'] !== T_COMMA
