@@ -20,7 +20,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_ControlStructures_ControlSignatureSniff implements PHP_CodeSniffer_Sniff
@@ -128,21 +128,30 @@ class Squiz_Sniffs_ControlStructures_ControlSignatureSniff implements PHP_CodeSn
                         $phpcsFile->fixer->addContent($closer, ' ');
                     } else {
                         $phpcsFile->fixer->beginChangeset();
-                        $phpcsFile->fixer->addContent($closer, ' '.$tokens[$opener]['content']);
-                        $phpcsFile->fixer->replaceToken($opener, '');
-
-                        if ($tokens[$opener]['line'] !== $tokens[$closer]['line']) {
-                            $next = $phpcsFile->findNext(T_WHITESPACE, ($opener + 1), null, true);
-                            if ($tokens[$next]['line'] !== $tokens[$opener]['line']) {
-                                for ($i = ($opener + 1); $i < $next; $i++) {
+                        if (trim($content) === '') {
+                            $phpcsFile->fixer->addContent($closer, ' ');
+                            if ($found !== 0) {
+                                for ($i = ($closer + 1); $i < $opener; $i++) {
                                     $phpcsFile->fixer->replaceToken($i, '');
                                 }
                             }
+                        } else {
+                            $phpcsFile->fixer->addContent($closer, ' '.$tokens[$opener]['content']);
+                            $phpcsFile->fixer->replaceToken($opener, '');
+
+                            if ($tokens[$opener]['line'] !== $tokens[$closer]['line']) {
+                                $next = $phpcsFile->findNext(T_WHITESPACE, ($opener + 1), null, true);
+                                if ($tokens[$next]['line'] !== $tokens[$opener]['line']) {
+                                    for ($i = ($opener + 1); $i < $next; $i++) {
+                                        $phpcsFile->fixer->replaceToken($i, '');
+                                    }
+                                }
+                            }
                         }
 
                         $phpcsFile->fixer->endChangeset();
-                    }
-                }
+                    }//end if
+                }//end if
             }//end if
         }//end if
 
