@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sniff
@@ -109,6 +109,24 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
             }
         }//end if
 
+        $previousToken = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true, null, true);
+        if ($previousToken !== false) {
+            // A list of tokens that indicate that the token is not
+            // part of an arithmetic operation.
+            $invalidTokens = array(
+                              T_COMMA,
+                              T_COLON,
+                              T_OPEN_PARENTHESIS,
+                              T_OPEN_SQUARE_BRACKET,
+                              T_OPEN_SHORT_ARRAY,
+                              T_CASE,
+                             );
+
+            if (in_array($tokens[$previousToken]['code'], $invalidTokens) === true) {
+                return;
+            }
+        }
+
         // Tokens that are allowed inside a bracketed operation.
         $allowed = array(
                     T_VARIABLE,
@@ -201,25 +219,8 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
 
         if ($lastBracket === false) {
             // It is not in a bracketed statement at all.
-            $previousToken = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true, null, true);
-            if ($previousToken !== false) {
-                // A list of tokens that indicate that the token is not
-                // part of an arithmetic operation.
-                $invalidTokens = array(
-                                  T_COMMA,
-                                  T_COLON,
-                                  T_OPEN_PARENTHESIS,
-                                  T_OPEN_SQUARE_BRACKET,
-                                  T_OPEN_SHORT_ARRAY,
-                                  T_CASE,
-                                 );
-
-                if (in_array($tokens[$previousToken]['code'], $invalidTokens) === false) {
-                    $this->addMissingBracketsError($phpcsFile, $stackPtr);
-                }
-
-                return;
-            }
+            $this->addMissingBracketsError($phpcsFile, $stackPtr);
+            return;
         } else if ($tokens[$lastBracket]['parenthesis_closer'] < $stackPtr) {
             // There are a set of brackets in front of it that don't include it.
             $this->addMissingBracketsError($phpcsFile, $stackPtr);
