@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Strings_EchoedStringsSniff implements PHP_CodeSniffer_Sniff
@@ -88,7 +88,11 @@ class Squiz_Sniffs_Strings_EchoedStringsSniff implements PHP_CodeSniffer_Sniff
             if ($fix === true) {
                 $phpcsFile->fixer->beginChangeset();
                 $phpcsFile->fixer->replaceToken($firstContent, '');
-                $phpcsFile->fixer->replaceToken(($end - 1), '');
+                if ($tokens[($firstContent - 1)]['code'] !== T_WHITESPACE) {
+                    $phpcsFile->fixer->addContent(($firstContent - 1), ' ');
+                }
+
+                $phpcsFile->fixer->replaceToken($prev, '');
                 $phpcsFile->fixer->endChangeset();
             }
         }
