@@ -1,4 +1,4 @@
-// do ... while
+
 i = 0;
 do {
     i = 0;
@@ -21,7 +21,6 @@ do{
     i = 0;
 }while(i > 0);
 
-// while
 while (i < 1) {
     i = 0;
 }
@@ -32,7 +31,6 @@ while(i < 1){
 
 while (i < 1) { i = 0; }
 
-// for
 for (i = 1; i < 1; i++) {
     i = 0;
 }
@@ -43,7 +41,6 @@ for(i = 1; i < 1; i++){
 
 for (i = 1; i < 1; i++) { i = 0; }
 
-// if
 if (i == 0) {
     i = 1;
 }
@@ -54,7 +51,6 @@ if(i == 0){
 
 if (i == 0) { i = 1; }
 
-// else
 if (i == 0) {
     i = 1;
 } else {
@@ -69,14 +65,6 @@ if (i == 0) {
 
 if (i == 0) { i = 1; } else { i = 0; }
 
-// else
-if (i == 0) {
-    i = 1;
-} else {
-    i = 0;
-}
-
-// else if
 if (i == 0) {
     i = 1;
 } else if (i == 2) {
@@ -85,30 +73,30 @@ if (i == 0) {
 
 if (i == 0) {
     i = 1;
-}else if(i == 2){
+}else   if(i == 2){
     i = 0;
 }
 
 if (i == 0) { i = 1; } else if (i == 2) { i = 0; }
 
-if (i == 0) { // comments are not allowed
+if (i == 0) { // comments are allowed
     i = 1;
 }
 
-if (i == 0) {// comments are not allowed
+if (i == 0) {// comments are allowed
     i = 1;
 }
 
-if (i == 0) { /* comments are not allowed*/
+if (i == 0) { /* comments are allowed*/
     i = 1;
 }
 
 if (i == 0)
-{ // this is not ok
+{ // this is ok
     i = 1;
 }
 
-if (i == 0) /* this is not ok */ {
+if (i == 0) /* this is ok */ {
 }
 
 try {
@@ -122,4 +110,20 @@ try { code = 'this'; } catch (e) {
 }
 
 do { i = 0;
-} while (i > 0);
\ No newline at end of file
+} while (i > 0);
+
+if (i === 0) {
+
+    i = 1
+}
+
+if (window.jQuery)(function($) {
+    $.fn.reset = function() {
+        return this.each(function() {
+            try {
+                this.reset();
+            } catch (e) {
+            }
+        });
+    };
+})(jQuery);
