@@ -20,7 +20,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2012 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Tokenizers_Comment
@@ -85,6 +85,10 @@ class PHP_CodeSniffer_Tokenizers_Comment
                      'comment_opener' => $openPtr,
                     );
 
+        if ($closeTag['content'] === false) {
+            $closeTag['content'] = '';
+        }
+
         $string = rtrim($string, '/*');
 
         /*
