@@ -20,7 +20,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Tokenizers_PHP
@@ -678,6 +678,30 @@ class PHP_CodeSniffer_Tokenizers_PHP
                 continue;
             }
 
+            /*
+                Tokens after a double colon may be look like scope openers,
+                such as when writing code like Foo::NAMESAPCE, but they are
+                only ever variables or strings.
+            */
+
+            if ($stackPtr > 1
+                && $tokens[($stackPtr - 1)][0] === T_PAAMAYIM_NEKUDOTAYIM
+                && $tokenIsArray === true
+                && $token[0] !== T_STRING
+                && $token[0] !== T_VARIABLE
+                && $token[0] !== T_DOLLAR
+                && isset(PHP_CodeSniffer_Tokens::$emptyTokens[$token[0]]) === false
+            ) {
+                $newToken            = array();
+                $newToken['code']    = T_STRING;
+                $newToken['type']    = 'T_STRING';
+                $newToken['content'] = $token[1];
+                $finalTokens[$newStackPtr] = $newToken;
+
+                $newStackPtr++;
+                continue;
+            }
+
             /*
                 Before PHP 7, the <=> operator was tokenized as
                 T_IS_SMALLER_OR_EQUAL followed by T_GREATER_THAN.
@@ -708,6 +732,7 @@ class PHP_CodeSniffer_Tokenizers_PHP
                 && $token[0] === T_STRING
                 && strtolower($token[1]) === 'trait'
                 && $tokens[($stackPtr - 1)][0] !== T_OBJECT_OPERATOR
+                && $tokens[($stackPtr - 1)][0] !== T_PAAMAYIM_NEKUDOTAYIM
             ) {
                 $finalTokens[$newStackPtr] = array(
                                               'content' => $token[1],
@@ -945,7 +970,8 @@ class PHP_CodeSniffer_Tokenizers_PHP
 
                 // This is a special case for the PHP 5.5 classname::class syntax
                 // where "class" should be T_STRING instead of T_CLASS.
-                if ($newToken['code'] === T_CLASS
+                if (($newToken['code'] === T_CLASS
+                    || $newToken['code'] === T_FUNCTION)
                     && $finalTokens[($newStackPtr - 1)]['code'] === T_DOUBLE_COLON
                 ) {
                     $newToken['code'] = T_STRING;
@@ -1268,25 +1294,6 @@ class PHP_CodeSniffer_Tokenizers_PHP
                         echo "\t* token $x on line $line changed from $type to T_STRING".PHP_EOL;
                     }
 
-                    $tokens[$x]['code'] = T_STRING;
-                    $tokens[$x]['type'] = 'T_STRING';
-                }
-            } else if ($tokens[$i]['code'] === T_PAAMAYIM_NEKUDOTAYIM) {
-                // Context sensitive keywords support.
-                for ($x = ($i + 1); $i < $numTokens; $x++) {
-                    if (isset(PHP_CodeSniffer_Tokens::$emptyTokens[$tokens[$x]['code']]) === false) {
-                        // Non-whitespace content.
-                        break;
-                    }
-                }
-
-                if (in_array($tokens[$x]['code'], array(T_STRING, T_VARIABLE, T_DOLLAR), true) === false) {
-                    if (PHP_CODESNIFFER_VERBOSITY > 1) {
-                        $line = $tokens[$x]['line'];
-                        $type = $tokens[$x]['type'];
-                        echo "\t* token $x on line $line changed from $type to T_STRING".PHP_EOL;
-                    }
-
                     $tokens[$x]['code'] = T_STRING;
                     $tokens[$x]['type'] = 'T_STRING';
                 }
