@@ -31,12 +31,19 @@ require_once dirname(__FILE__).'/AbstractSniffUnitTest.php';
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.7.0
+ * @version   Release: 2.7.1
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Standards_AllSniffs
 {
 
+    /**
+     * A list of test file paths without a corresponding sniff file.
+     *
+     * @var array
+     */
+    public static $orphanedTests = array();
+
 
     /**
      * Prepare the test runner.
@@ -64,6 +71,14 @@ class PHP_CodeSniffer_Standards_AllSniffs
 
         $isInstalled = !is_file(dirname(__FILE__).'/../../CodeSniffer.php');
 
+        // Optionally allow for ignoring the tests for one or more standards.
+        $ignoreTestsForStandards = getenv('PHPCS_IGNORE_TESTS');
+        if ($ignoreTestsForStandards === false) {
+            $ignoreTestsForStandards = array();
+        } else {
+            $ignoreTestsForStandards = explode(',', $ignoreTestsForStandards);
+        }
+
         $installedPaths = PHP_CodeSniffer::getInstalledStandardPaths();
         foreach ($installedPaths as $path) {
             $path      = realpath($path);
@@ -80,6 +95,10 @@ class PHP_CodeSniffer_Standards_AllSniffs
             }
 
             foreach ($standards as $standard) {
+                if (in_array($standard, $ignoreTestsForStandards, true)) {
+                    continue;
+                }
+
                 $testsDir = $path.DIRECTORY_SEPARATOR.$standard.DIRECTORY_SEPARATOR.'Tests'.DIRECTORY_SEPARATOR;
 
                 if (is_dir($testsDir) === false) {
@@ -108,14 +127,22 @@ class PHP_CodeSniffer_Standards_AllSniffs
                     $className = str_replace(DIRECTORY_SEPARATOR, '_', $className);
 
                     // Include the sniff here so tests can use it in their setup() methods.
-                    $parts     = explode('_', $className);
-                    $sniffPath = $origPath.DIRECTORY_SEPARATOR.$parts[0].DIRECTORY_SEPARATOR.'Sniffs'.DIRECTORY_SEPARATOR.$parts[2].DIRECTORY_SEPARATOR.$parts[3];
-                    $sniffPath = substr($sniffPath, 0, -8).'Sniff.php';
-                    include_once $sniffPath;
+                    $parts = explode('_', $className);
+                    if (isset($parts[0],$parts[2],$parts[3]) === true) {
+                        $sniffPath = $origPath.DIRECTORY_SEPARATOR.$parts[0].DIRECTORY_SEPARATOR.'Sniffs'.DIRECTORY_SEPARATOR.$parts[2].DIRECTORY_SEPARATOR.$parts[3];
+                        $sniffPath = substr($sniffPath, 0, -8).'Sniff.php';
 
-                    include_once $filePath;
-                    $GLOBALS['PHP_CODESNIFFER_STANDARD_DIRS'][$className] = $path;
-                    $suite->addTestSuite($className);
+                        if (file_exists($sniffPath) === true) {
+                            include_once $sniffPath;
+                            include_once $filePath;
+                            $GLOBALS['PHP_CODESNIFFER_STANDARD_DIRS'][$className] = $path;
+                            $suite->addTestSuite($className);
+                        } else {
+                            self::$orphanedTests[] = $filePath;
+                        }
+                    } else {
+                        self::$orphanedTests[] = $filePath;
+                    }
                 }//end foreach
             }//end foreach
         }//end foreach
